@@ -46,85 +46,68 @@ EngineRestGitHub <- R6::R6Class(
       return(files_table)
     },
 
-    # Pulling repositories where code appears
-    get_repos_by_code = function(code,
-                                 org = NULL,
-                                 repos = NULL,
-                                 filename = NULL,
-                                 in_path = FALSE,
-                                 output = "table_full",
-                                 verbose = TRUE,
-                                 progress = TRUE) {
-      if (is.null(repos)) {
-        search_result <- private$search_for_code(
-          code = code,
-          org = org,
-          filename = filename,
-          in_path = in_path,
-          verbose = verbose,
-          progress = progress
+    search_for_code = function(code,
+                               org = NULL,
+                               filename = NULL,
+                               in_path = FALSE,
+                               verbose = TRUE) {
+      user_query <- if (!is.null(org)) {
+        paste0('+user:', org)
+      } else {
+        ''
+      }
+      query <- if (!in_path) {
+        paste0('"', code, '"', user_query)
+      } else {
+        paste0('"', code, '"+in:path', user_query)
+      }
+      if (!is.null(filename)) {
+        query <- paste0(query, '+in:file+filename:', filename)
+      }
+      search_endpoint <- paste0(private$endpoints[["search"]], query)
+      if (verbose) cli::cli_alert("Searching for code [{code}]...")
+      total_n <- self$response(search_endpoint)[["total_count"]]
+      search_result <- if (length(total_n) > 0) {
+        private$search_response(
+          search_endpoint = search_endpoint,
+          total_n = total_n
         )
       } else {
-        search_result <- private$search_repos_for_code(
-          code = code,
-          repos = repos,
-          filename = filename,
-          in_path = in_path,
-          verbose = verbose,
-          progress = progress
-        )
+        list()
       }
-      if (length(search_result) > 0) {
-        if (output == "table_full" || output == "table_min") {
-          search_output <- private$map_search_into_repos(
-            search_response = search_result,
-            progress        = progress
-          )
-        } else if (output == "raw") {
-          search_output <- search_result
-        }
-      } else {
-        search_output <- list()
-      }
-      return(search_output)
+      return(search_result)
     },
 
-    # Retrieve only important info from repositories response
-    tailor_repos_response = function(repos_response, output = "table_full") {
-      repos_list <- purrr::map(repos_response, function(repo) {
-        if (output == "table_full") {
-          repo_data <- list(
-            "repo_id" = repo$id,
-            "repo_name" = repo$name,
-            "default_branch" = repo$default_branch,
-            "stars" = repo$stargazers_count,
-            "forks" = repo$forks_count,
-            "created_at" = gts_to_posixt(repo$created_at),
-            "last_activity_at" = if (!is.null(repo$pushed_at)) {
-              gts_to_posixt(repo$pushed_at)
-            } else {
-              gts_to_posixt(repo$created_at)
-            },
-            "languages" = repo$language,
-            "issues_open" = repo$issues_open,
-            "issues_closed" = repo$issues_closed,
-            "organization" = repo$owner$login,
-            "repo_url" = repo$html_url
-          )
+    search_repos_for_code = function(code,
+                                     repos,
+                                     filename = NULL,
+                                     in_path = FALSE,
+                                     verbose = TRUE) {
+      if (verbose) cli::cli_alert("Searching for code [{code}]...")
+      search_result <- purrr::map(repos, function(repo) {
+        repo_query <- paste0('+repo:', repo)
+        query <- if (!in_path) {
+          paste0('"', code, '"', repo_query)
+        } else {
+          paste0('"', code, '"+in:path', repo_query)
         }
-        if (output == "table_min") {
-          repo_data <- list(
-            "repo_id" = repo$id,
-            "repo_name" = repo$name,
-            "default_branch" = repo$default_branch,
-            "created_at" = gts_to_posixt(repo$created_at),
-            "organization" = repo$owner$login,
-            "repo_url" = repo$html_url
-          )
+        if (!is.null(filename)) {
+          query <- paste0(query, '+in:file+filename:', filename)
         }
-        return(repo_data)
-      })
-      return(repos_list)
+        search_endpoint <- paste0(private$endpoints[["search"]], query)
+        total_n <- self$response(search_endpoint)[["total_count"]]
+        result <- if (length(total_n) > 0) {
+          private$search_response(
+            search_endpoint = search_endpoint,
+            total_n = total_n
+          )
+        } else {
+          list()
+        }
+        return(result)
+      }) |>
+        purrr::list_flatten()
+      return(search_result)
     },
 
     #' Pull all repositories URLS from organization
@@ -153,30 +136,6 @@ EngineRestGitHub <- R6::R6Class(
       return(repos_urls)
     },
 
-    #' A method to add information on open and closed issues of a repository.
-    get_repos_issues = function(repos_table, progress) {
-      if (nrow(repos_table) > 0) {
-        repos_iterator <- paste0(repos_table$organization, "/", repos_table$repo_name)
-        issues <- purrr::map_dfr(repos_iterator, function(repo_path) {
-          issues_endpoint <- paste0(private$endpoints[["repositories"]], repo_path, "/issues")
-          issues <- self$response(
-            endpoint = issues_endpoint
-          )
-          data.frame(
-            "open" = length(purrr::keep(issues, ~ .$state == "open")),
-            "closed" = length(purrr::keep(issues, ~ .$state == "closed"))
-          )
-        }, .progress = if (progress) {
-          "Pulling repositories issues..."
-        } else {
-          FALSE
-        })
-        repos_table$issues_open <- issues$open
-        repos_table$issues_closed <- issues$closed
-      }
-      return(repos_table)
-    },
-
     #' Add information on repository contributors.
     get_repos_contributors = function(repos_table, progress) {
       if (nrow(repos_table) > 0) {
@@ -228,72 +187,6 @@ EngineRestGitHub <- R6::R6Class(
       )
     },
 
-    search_for_code = function(code,
-                               org,
-                               filename,
-                               in_path,
-                               verbose,
-                               progress) {
-      user_query <- if (!is.null(org)) {
-        paste0('+user:', org)
-      } else {
-        ''
-      }
-      query <- if (!in_path) {
-        paste0('"', code, '"', user_query)
-      } else {
-        paste0('"', code, '"+in:path', user_query)
-      }
-      if (!is.null(filename)) {
-        query <- paste0(query, '+in:file+filename:', filename)
-      }
-      search_endpoint <- paste0(private$endpoints[["search"]], query)
-      if (verbose) cli::cli_alert_info("Searching for code [{code}]...")
-      total_n <- self$response(search_endpoint)[["total_count"]]
-      search_result <- if (length(total_n) > 0) {
-        private$search_response(
-          search_endpoint = search_endpoint,
-          total_n = total_n
-        )
-      } else {
-        list()
-      }
-      return(search_result)
-    },
-
-    search_repos_for_code = function(code,
-                                     repos,
-                                     filename,
-                                     in_path,
-                                     verbose,
-                                     progress) {
-      if (verbose) cli::cli_alert_info("Searching for code [{code}]...")
-      search_result <- purrr::map(repos, function(repo) {
-        repo_query <- paste0('+repo:', repo)
-        query <- if (!in_path) {
-          paste0('"', code, '"', repo_query)
-        } else {
-          paste0('"', code, '"+in:path', repo_query)
-        }
-        if (!is.null(filename)) {
-          query <- paste0(query, '+in:file+filename:', filename)
-        }
-        search_endpoint <- paste0(private$endpoints[["search"]], query)
-        total_n <- self$response(search_endpoint)[["total_count"]]
-        result <- if (length(total_n) > 0) {
-          private$search_response(
-            search_endpoint = search_endpoint,
-            total_n = total_n
-          )
-        } else {
-          list()
-        }
-        return(result)
-      }) |>
-        purrr::list_flatten()
-      return(search_result)
-    },
-
     # A wrapper for proper pagination of GitHub search REST API
     # @param search_endpoint A character, a search endpoint
     # @param total_n Number of results
@@ -375,22 +268,6 @@ EngineRestGitHub <- R6::R6Class(
       }
     },
 
-    # Parse search response into repositories output
-    map_search_into_repos = function(search_response, progress) {
-      repos_ids <- purrr::map_chr(search_response, ~ as.character(.$repository$id)) %>%
-        unique()
-      repos_list <- purrr::map(repos_ids, function(repo_id) {
-        content <- self$response(
-          endpoint = paste0(self$rest_api_url, "/repositories/", repo_id)
-        )
-      }, .progress = if (progress) {
-        "Parsing search response into respositories output..."
-      } else {
-        FALSE
-      })
-      repos_list
-    },
-
     # Get files content
     get_files_content = function(search_result, filename) {
       purrr::map(search_result, ~ self$response(.$url),
