@@ -5,26 +5,32 @@
 GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
   public = list(
 
-    #' @description Prepare query to list groups from GitLab.
-    #' @return A query.
     groups = function() {
-      'query GetGroups($groupCursor: String!) {
+      paste0(
+        'query GetGroups($groupCursor: String!) {
             groups (after: $groupCursor) {
               pageInfo {
                 endCursor
                 hasNextPage
               }
               edges {
-                node {
-                  fullPath
-                }
+                node {', private$group_fields, '}
               }
             }
         }'
+      )
+    },
+
+    group = function() {
+      paste0('
+      query GetGroup($org: ID!) {
+        group(fullPath: $org) {',
+             private$group_fields
+             , '}
+      }
+    ')
     },
 
-    #' @field user_or_org_query Query to check if a given string is user or
-    #'   organization.
     user_or_org_query =
       '
       query ($username: String! $grouppath: ID!) {
@@ -39,8 +45,15 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
       }'
     ,
 
-    #' @description Prepare query to get repositories from GitLab.
-    #' @return A query.
+    repos = function(repo_cursor) {
+      paste0('
+        query GetRepo($projects_ids: [ID!]!) {
+          projects(ids: $projects_ids first:100', private$add_cursor(repo_cursor), ') {
+          ', private$projects_field_content, '
+          }
+        }')
+    },
+
     repos_by_org = function() {
       paste0('
         query GetReposByOrg($org: ID! $repo_cursor: String!) {
@@ -52,8 +65,6 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
         }')
     },
 
-    #' @description Prepare query to get repositories from GitLab.
-    #' @return A query.
     repos_by_user = function() {
       paste0('
         query GetUserRepos ($username: String! $repo_cursor: String!) {
@@ -63,8 +74,36 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
         }')
     },
 
-    #' @description Prepare query to get info on a GitLab user.
-    #' @return A query.
+    issues_from_repo = function(issues_cursor = "") {
+      paste0('
+      query getIssuesFromRepo ($fullPath: ID!) {
+          project(fullPath: $fullPath) {
+            issues(first: 100
+                   ', private$add_cursor(issues_cursor), ') {
+              pageInfo {
+                hasNextPage
+      				  endCursor
+      				}
+              edges {
+                node {
+                  number: iid
+                  title
+                  description
+                  created_at: createdAt
+                  closed_at: closedAt
+                  state
+                  url: webUrl
+                  author {
+                    login: username
+                  }
+                }
+              }
+            }
+          }
+        }
+      ')
+    },
+
     user = function() {
       paste0('
         query GetUser($user: String!) {
@@ -90,21 +129,12 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
       ')
     },
 
-    #' @description Prepare query to get files in a standard filepath from
-    #'   GitLab repositories.
-    #' @param end_cursor An endCursor.
-    #' @return A query.
     files_by_org = function(end_cursor = "") {
-      if (nchar(end_cursor) == 0) {
-        after_cursor <- end_cursor
-      } else {
-        after_cursor <- paste0('after: "', end_cursor, '" ')
-      }
       paste0(
         'query GetFilesByOrg($org: ID!, $file_paths: [String!]!) {
             group(fullPath: $org) {
               projects(first: 100',
-        after_cursor,
+        private$add_cursor(end_cursor),
         ') {
           count
           pageInfo {
@@ -185,8 +215,6 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
       '
     },
 
-    #' @description Prepare query to get releases from GitHub repositories.
-    #' @return A query.
     releases_from_repo = function() {
       'query GetReleasesFromRepo($project_path: ID!) {
               project(fullPath: $project_path) {
@@ -208,6 +236,26 @@ GQLQueryGitLab <- R6::R6Class("GQLQueryGitLab",
     }
   ),
   private = list(
+    add_cursor = function(cursor) {
+      if (nchar(cursor) == 0) {
+        cursor_argument <- cursor
+      } else {
+        cursor_argument <- paste0('after: "', cursor, '"')
+      }
+      return(cursor_argument)
+    },
+
+    group_fields =
+      '
+      name
+      description
+      fullPath
+      webUrl
+      projectsCount
+      groupMembersCount
+      avatarUrl
+    ',
+
     projects_field_content =
       '
       count
