@@ -138,17 +138,37 @@ GitHostGitHub <- R6::R6Class(
       return(repos_table)
     },
 
+    get_orgs_from_host = function(output, verbose) {
+      graphql_engine <- private$engines$graphql
+      orgs <- graphql_engine$get_orgs(
+        output = output,
+        verbose = verbose
+      )
+      if (output == "full_table") {
+        orgs <- orgs |>
+          graphql_engine$prepare_orgs_table()
+        private$orgs <- dplyr::pull(orgs, path)
+      } else {
+        private$orgs <- orgs
+      }
+      return(orgs)
+    },
+
+    get_repos_ids = function(search_response) {
+      purrr::map_vec(search_response, ~.$repository$node_id) |> unique()
+    },
+
     # Get projects URL from search response
     get_repo_url_from_response = function(search_response, repos_fullnames = NULL, type, progress = TRUE) {
       if (!is.null(repos_fullnames)) {
         search_response <- search_response |>
-          purrr::keep(~ .$repository$full_name %in% repos_fullnames)
+          purrr::keep(~ paste0(.$organization$login, "/", .$repo_name) %in% repos_fullnames)
       }
       purrr::map_vec(search_response, function(project) {
         if (type == "api") {
-          project$repository$url
+          paste0(private$api_url, "/repos/", project$organization$login, "/", project$repo_name)
         } else {
-          project$repository$html_url
+          project$repo_url
         }
       })
     },
@@ -202,7 +222,7 @@ GitHostGitHub <- R6::R6Class(
             show_message(
               host = private$host_name,
               engine = "graphql",
-              scope = paste0(org, "/", private$orgs_repos[[org]], collapse = ", "),
+              scope = set_repo_scope(org, private),
               information = "Pulling commits"
             )
           }
