@@ -1,3 +1,16 @@
+integration_tests_skipped <- Sys.getenv("GITSTATS_INTEGRATION_TEST_SKIPPED", unset = "true") |>
+  as.logical()
+
+if (integration_tests_skipped) {
+  github_token <- NULL
+  github_org <- "test_org"
+  gitlab_group <- "test_group"
+} else {
+  github_token <- Sys.getenv("GITHUB_PAT")
+  github_org <- "r-world-devs"
+  gitlab_group <- "mbtests"
+}
+
 test_mocker <- Mocker$new()
 
 test_gitstats <- create_test_gitstats(hosts = 2)
@@ -14,7 +27,7 @@ test_rest_github_priv <- environment(test_rest_github$initialize)$private
 
 test_graphql_github <- EngineGraphQLGitHub$new(
   gql_api_url = "https://api.github.com/graphql",
-  token = NULL
+  token = github_token
 )
 test_graphql_github_priv <- environment(test_graphql_github$initialize)$private
 
@@ -30,10 +43,22 @@ test_graphql_gitlab <- EngineGraphQLGitLab$new(
 )
 test_graphql_gitlab_priv <- environment(test_graphql_gitlab$initialize)$private
 
-github_testhost <- create_github_testhost(orgs = "test_org")
+github_testhost <- create_github_testhost(
+  orgs = github_org,
+  token = github_token
+)
 
-github_testhost_priv <- create_github_testhost(orgs = "test_org", mode = "private")
+github_testhost_priv <- create_github_testhost(
+  orgs = github_org,
+  token = github_token,
+  mode = "private"
+)
 
-gitlab_testhost <- create_gitlab_testhost(orgs = "test_group")
+gitlab_testhost <- create_gitlab_testhost(
+  orgs = gitlab_group
+)
 
-gitlab_testhost_priv <- create_gitlab_testhost(orgs = "test_group", mode = "private")
+gitlab_testhost_priv <- create_gitlab_testhost(
+  orgs = gitlab_group,
+  mode = "private"
+)
