@@ -7,6 +7,39 @@ test_that("repos_by_org query is built properly", {
   test_mocker$cache(gh_repos_by_org_query)
 })
 
+test_that("repos_by_user query is built properly", {
+  gh_repos_by_user_query <-
+    test_gqlquery_gh$repos_by_user(repo_cursor = "")
+  expect_snapshot(
+    gh_repos_by_user_query
+  )
+  test_mocker$cache(gh_repos_by_user_query)
+})
+
+test_that("repos_by_ids query is built properly", {
+  gh_repos_by_ids_query <-
+    test_gqlquery_gh$repos_by_ids()
+  expect_snapshot(
+    gh_repos_by_ids_query
+  )
+  test_mocker$cache(gh_repos_by_ids_query)
+})
+
+
+if (integration_tests_skipped) {
+  gh_org <- "test_org"
+  gh_user <- "test_user"
+  gh_repo <- "TestRepo"
+  gh_code <- "test_code"
+  gh_file <- "test_file"
+} else {
+  gh_org <- "r-world-devs"
+  gh_repo <- "GitStats"
+  gh_user <- "maciekbanas"
+  gh_code <- "dplyr"
+  gh_file <- "DESCRIPTION"
+}
+
 test_that("`get_repos_page()` pulls repos page from GitHub organization", {
   mockery::stub(
     test_graphql_github_priv$get_repos_page,
@@ -14,15 +47,30 @@ test_that("`get_repos_page()` pulls repos page from GitHub organization", {
     test_fixtures$github_repos_by_org_response
   )
   gh_repos_page <- test_graphql_github_priv$get_repos_page(
-    login = "test_org",
+    login = gh_org,
     type = "organization"
   )
   expect_gh_repos_gql_response(
-    gh_repos_page
+    gh_repos_page$data$repositoryOwner$repositories$nodes[[1]]
   )
   test_mocker$cache(gh_repos_page)
 })
 
+test_that("get_repos() pulls repositories by ids", {
+  mockery::stub(
+    test_graphql_github$get_repos,
+    "self$gql_response",
+    test_fixtures$github_repos_by_ids_response
+  )
+  gh_repos_by_ids <- test_graphql_github$get_repos(
+    repos_ids = c("repo_1", "repo_2", "repo_3")
+  )
+  expect_gh_repos_gql_response(
+    gh_repos_by_ids[[1]]
+  )
+  test_mocker$cache(gh_repos_by_ids)
+})
+
 test_that("`get_repos_from_org()` prepares formatted list", {
   mockery::stub(
     test_graphql_github$get_repos_from_org,
@@ -30,7 +78,7 @@ test_that("`get_repos_from_org()` prepares formatted list", {
     test_mocker$use("gh_repos_page")
   )
   gh_repos_from_org <- test_graphql_github$get_repos_from_org(
-    org = "test_org",
+    org = gh_org,
     type = "organization"
   )
   expect_list_contains(
@@ -51,12 +99,11 @@ test_that("`get_repos_page()` pulls repos page from GitHub user", {
     test_fixtures$github_repos_by_user_response
   )
   gh_repos_user_page <- test_graphql_github_priv$get_repos_page(
-    login = "test_user",
+    login = gh_user,
     type = "user"
   )
   expect_gh_repos_gql_response(
-    gh_repos_user_page,
-    type = "user"
+    gh_repos_user_page$data$user$repositories$nodes[[1]]
   )
   test_mocker$cache(gh_repos_user_page)
 })
@@ -68,7 +115,7 @@ test_that("`get_repos_from_org()` prepares formatted list", {
     test_mocker$use("gh_repos_user_page")
   )
   gh_repos_from_user <- test_graphql_github$get_repos_from_org(
-    org = "test_user",
+    org = gh_user,
     type = "user"
   )
   expect_list_contains(
@@ -114,43 +161,23 @@ test_that("`search_response()` performs search with limit over 1000", {
   test_mocker$cache(gh_search_repos_response)
 })
 
-test_that("Mapping search result to repositories works", {
-  mockery::stub(
-    test_rest_github_priv$map_search_into_repos,
-    "self$response",
-    test_fixtures$github_repository_rest_response
-  )
-  gh_mapped_repos <- test_rest_github_priv$map_search_into_repos(
-    search_response = test_mocker$use("gh_search_repos_response"),
-    progress = FALSE
-  )
-  expect_gh_repos_rest_response(gh_mapped_repos)
-  test_mocker$cache(gh_mapped_repos)
-})
-
 test_that("`search_for_code()` returns repos output for code search in files", {
   mockery::stub(
-    test_rest_github_priv$search_for_code,
+    test_rest_github$search_for_code,
     "self$response",
     list("total_count" = 3L)
   )
   mockery::stub(
-    test_rest_github_priv$search_for_code,
+    test_rest_github$search_for_code,
     "private$search_response",
     test_fixtures$github_search_response
   )
-  mockery::stub(
-    test_rest_github_priv$search_for_code,
-    "private$map_search_into_repos",
-    test_mocker$use("gh_mapped_repos")
-  )
-  gh_search_for_code <- test_rest_github_priv$search_for_code(
-    code     = "test_code",
-    filename = "test_file",
-    in_path  = FALSE,
-    org      = "test_org",
-    verbose  = FALSE,
-    progress = FALSE
+  gh_search_for_code <- test_rest_github$search_for_code(
+    code = gh_code,
+    filename = gh_file,
+    in_path = FALSE,
+    org = gh_org,
+    verbose = FALSE
   )
   expect_gh_search_response(gh_search_for_code$items)
   test_mocker$cache(gh_search_for_code)
@@ -158,128 +185,30 @@ test_that("`search_for_code()` returns repos output for code search in files", {
 
 test_that("`search_repos_for_code()` returns repos output for code search in files", {
   mockery::stub(
-    test_rest_github_priv$search_repos_for_code,
+    test_rest_github$search_repos_for_code,
     "self$response",
     list("total_count" = 3L)
   )
   mockery::stub(
-    test_rest_github_priv$search_repos_for_code,
+    test_rest_github$search_repos_for_code,
     "private$search_response",
     test_fixtures$github_search_response
   )
-  mockery::stub(
-    test_rest_github_priv$search_repos_for_code,
-    "private$map_search_into_repos",
-    test_mocker$use("gh_mapped_repos")
-  )
-  gh_search_repos_for_code <- test_rest_github_priv$search_repos_for_code(
-    code     = "test_code",
-    filename = "test_file",
-    in_path  = FALSE,
-    repos    = c("TestRepo", "TestRepo1"),
-    verbose  = FALSE,
-    progress = FALSE
+  gh_search_repos_for_code <- test_rest_github$search_repos_for_code(
+    code = gh_code,
+    filename = gh_file,
+    in_path = FALSE,
+    repos = gh_org,
+    verbose = FALSE
   )
   expect_gh_search_response(gh_search_repos_for_code$items)
   test_mocker$cache(gh_search_repos_for_code)
 })
 
-test_that("`get_repos_by_code()` for GitHub prepares a raw search response", {
-  mockery::stub(
-    test_rest_github$get_repos_by_code,
-    "private$search_for_code",
-    test_mocker$use("gh_search_for_code")
-  )
-  mockery::stub(
-    test_rest_github$get_repos_by_code,
-    "private$search_repos_for_code",
-    test_mocker$use("gh_search_repos_for_code")
-  )
-  gh_repos_by_code_raw <- test_rest_github$get_repos_by_code(
-    code    = "test_code",
-    org     = "test_org",
-    output  = "raw",
-    verbose = FALSE
-  )
-  expect_gh_search_response(gh_repos_by_code_raw$items)
-  test_mocker$cache(gh_repos_by_code_raw)
-})
-
-test_that("`get_repos_by_code()` for GitHub prepares a repository output", {
-  mockery::stub(
-    test_rest_github$get_repos_by_code,
-    "private$search_for_code",
-    test_mocker$use("gh_search_for_code")
-  )
-  mockery::stub(
-    test_rest_github$get_repos_by_code,
-    "private$search_repos_for_code",
-    test_mocker$use("gh_search_repos_for_code")
-  )
-  mockery::stub(
-    test_rest_github$get_repos_by_code,
-    "private$map_search_into_repos",
-    test_mocker$use("gh_mapped_repos")
-  )
-  gh_repos_by_code <- test_rest_github$get_repos_by_code(
-    code    = "test_code",
-    org     = "test_org",
-    output  = "table_min",
-    verbose = FALSE
-  )
-  expect_gh_repos_rest_response(gh_repos_by_code)
-  test_mocker$cache(gh_repos_by_code)
-})
-
-test_that("GitHub tailors precisely `repos_list`", {
-  gh_repos_by_code <- test_mocker$use("gh_repos_by_code")
-  gh_repos_by_code_tailored <-
-    test_rest_github$tailor_repos_response(gh_repos_by_code)
-  gh_repos_by_code_tailored %>%
-    expect_type("list") %>%
-    expect_length(length(gh_repos_by_code))
-  expect_list_contains_only(
-    gh_repos_by_code_tailored[[1]],
-    c(
-      "repo_id", "repo_name", "created_at", "last_activity_at",
-      "forks", "stars", "issues_open", "issues_closed",
-      "organization"
-    )
-  )
-  expect_lt(
-    length(gh_repos_by_code_tailored[[1]]),
-    length(gh_repos_by_code[[1]])
-  )
-  test_mocker$cache(gh_repos_by_code_tailored)
-})
-
-test_that("GitHub tailors `repos_list` to minimal version of table", {
-  gh_repos_by_code <- test_mocker$use("gh_repos_by_code")
-  gh_repos_by_code_tailored_min <-
-    test_rest_github$tailor_repos_response(
-      repos_response = gh_repos_by_code,
-      output = "table_min"
-    )
-  gh_repos_by_code_tailored_min %>%
-    expect_type("list") %>%
-    expect_length(length(gh_repos_by_code))
-  expect_list_contains_only(
-    gh_repos_by_code_tailored_min[[1]],
-    c(
-      "repo_id", "repo_name", "created_at", "organization"
-    )
-  )
-  expect_lt(
-    length(gh_repos_by_code_tailored_min[[1]]),
-    length(gh_repos_by_code[[1]])
-  )
-  test_mocker$cache(gh_repos_by_code_tailored_min)
-})
-
 test_that("`prepare_repos_table()` prepares repos table", {
-  gh_repos_by_code_table <- test_rest_github$prepare_repos_table(
-      repos_list = test_mocker$use("gh_repos_by_code_tailored"),
-      verbose = FALSE
+  gh_repos_by_code_table <- test_graphql_github$prepare_repos_table(
+      repos_list = test_mocker$use("gh_repos_from_org"),
+      org = gh_org
   )
   expect_repos_table(
     gh_repos_by_code_table
@@ -287,90 +216,80 @@ test_that("`prepare_repos_table()` prepares repos table", {
   test_mocker$cache(gh_repos_by_code_table)
 })
 
-test_that("`prepare_repos_table()` prepares minimum version of repos table", {
-  gh_repos_by_code_table_min <- test_rest_github$prepare_repos_table(
-    repos_list = test_mocker$use("gh_repos_by_code_tailored_min"),
-    output = "table_min",
-    verbose = FALSE
+test_that("get_repos_ids", {
+  repos_ids <- github_testhost_priv$get_repos_ids(
+    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
-  expect_repos_table(
-    gh_repos_by_code_table_min,
-    repo_cols = repo_min_colnames
+  expect_type(
+    repos_ids,
+    "character"
+  )
+  expect_gt(
+    length(repos_ids), 0
   )
-  test_mocker$cache(gh_repos_by_code_table_min)
 })
 
-test_that("`get_repos_issues()` adds issues to repos table", {
+test_that("parse_search_response parses search response into repositories output", {
   mockery::stub(
-    test_rest_github$get_repos_issues,
-    "self$response",
-    test_fixtures$github_issues_response
+    github_testhost_priv$parse_search_response,
+    "graphql_engine$get_repos",
+    test_mocker$use("gh_repos_by_ids")
   )
-  gh_repos_by_code_table <- test_mocker$use("gh_repos_by_code_table")
-  suppressMessages(
-    gh_repos_by_code_table <- test_rest_github$get_repos_issues(
-      gh_repos_by_code_table,
-      progress = FALSE
-    )
+  gh_repos_raw_output <- github_testhost_priv$parse_search_response(
+    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]],
+    output = "raw"
   )
-  expect_gt(
-    length(gh_repos_by_code_table$issues_open),
-    0
+  expect_gh_repos_gql_response(gh_repos_raw_output[[1]])
+  test_mocker$cache(gh_repos_raw_output)
+})
+
+test_that("parse_search_response parses search response into repositories output", {
+  mockery::stub(
+    github_testhost_priv$parse_search_response,
+    "graphql_engine$get_repos_from_org",
+    test_mocker$use("gh_repos_from_org")
   )
-  expect_gt(
-    length(gh_repos_by_code_table$issues_closed),
-    0
+  gh_repos_by_code_table <- github_testhost_priv$parse_search_response(
+    search_response = test_mocker$use("gh_search_repos_for_code")[["items"]],
+    org = gh_org,
+    output = "table"
   )
+  expect_repos_table(gh_repos_by_code_table)
   test_mocker$cache(gh_repos_by_code_table)
 })
 
 test_that("`get_repos_with_code_from_orgs()` works", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code")
+    "rest_engine$search_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
-    "rest_engine$get_repos_issues",
+    "private$parse_search_response",
     test_mocker$use("gh_repos_by_code_table")
   )
   repos_with_code_from_orgs_full <- github_testhost_priv$get_repos_with_code_from_orgs(
     code = "shiny",
-    output = "table_full",
+    output = "table",
     verbose = FALSE
   )
   expect_repos_table(repos_with_code_from_orgs_full)
   test_mocker$cache(repos_with_code_from_orgs_full)
 })
 
-test_that("`get_repos_with_code_from_orgs()` pulls minimum version of table", {
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_orgs,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code")
-  )
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_orgs,
-    "rest_engine$prepare_repos_table",
-    test_mocker$use("gh_repos_by_code_table_min")
-  )
-  repos_with_code_from_orgs_min <- github_testhost_priv$get_repos_with_code_from_orgs(
-    code = "shiny",
-    output = "table_min",
-    verbose = FALSE
-  )
-  expect_repos_table(repos_with_code_from_orgs_min,
-                     repo_cols = repo_min_colnames)
-  test_mocker$cache(repos_with_code_from_orgs_min)
-})
-
 test_that("`get_repos_with_code_from_orgs()` pulls raw response", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_orgs,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code_raw")
+    "rest_engine$search_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
+  mockery::stub(
+    github_testhost_priv$get_repos_with_code_from_orgs,
+    "private$parse_search_response",
+    test_mocker$use("gh_repos_raw_output")
+  )
+  github_testhost_priv$orgs <- gh_org
   expect_snapshot(
     repos_with_code_from_orgs_raw <- github_testhost_priv$get_repos_with_code_from_orgs(
       code = "shiny",
@@ -386,19 +305,15 @@ test_that("`get_repos_with_code_from_orgs()` pulls raw response", {
 test_that("`get_repos_with_code_from_host()` pulls and parses output into table", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code_raw")
+    "rest_engine$search_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$prepare_repos_table",
-    test_mocker$use("gh_repos_by_code_table")
-  )
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$get_repos_issues",
+    "private$parse_search_response",
     test_mocker$use("gh_repos_by_code_table")
   )
+  github_testhost_priv$searching_scope <- "all"
   expect_snapshot(
     repos_with_code_from_host_table <- github_testhost_priv$get_repos_with_code_from_host(
       code = "DESCRIPTION",
@@ -417,58 +332,30 @@ test_that("`get_repos_with_code_from_repos()` works", {
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_repos,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code")
+    "rest_engine$search_repos_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_repos,
-    "rest_engine$get_repos_issues",
+    "private$parse_search_response",
     test_mocker$use("gh_repos_by_code_table")
   )
   github_testhost_priv$searching_scope <- c("repo")
   expect_snapshot(
     repos_with_code_from_repos_full <- github_testhost_priv$get_repos_with_code_from_repos(
       code = "tests",
-      output = "table_full",
+      output = "table",
       verbose = TRUE
     )
   )
   expect_repos_table(repos_with_code_from_repos_full)
 })
 
-test_that("`get_repos_with_code_from_repos()` pulls minimum version of table", {
-  github_testhost_priv <- create_github_testhost(
-    repos = c("TestRepo1", "TestRepo2"),
-    mode = "private"
-  )
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_repos,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code")
-  )
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code_from_repos,
-    "rest_engine$get_repos_issues",
-    test_mocker$use("gh_repos_by_code_table")
-  )
-  github_testhost_priv$searching_scope <- c("org", "repo")
-  expect_snapshot(
-    repos_with_code_from_repos_min <- github_testhost_priv$get_repos_with_code_from_repos(
-      code = "tests",
-      in_files = "DESCRIPTION",
-      output = "table_min",
-      verbose = TRUE
-    )
-  )
-  expect_repos_table(repos_with_code_from_repos_min,
-                     repo_cols = repo_min_colnames)
-})
-
 test_that("`get_repos_with_code_from_host()` pulls raw response", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code_raw")
+    "rest_engine$search_repos_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
   )
   expect_snapshot(
     repos_with_code_from_host_raw <- github_testhost_priv$get_repos_with_code_from_host(
@@ -483,8 +370,13 @@ test_that("`get_repos_with_code_from_host()` pulls raw response", {
 test_that("`get_repos_with_code_from_host()` pulls raw response", {
   mockery::stub(
     github_testhost_priv$get_repos_with_code_from_host,
-    "rest_engine$get_repos_by_code",
-    test_mocker$use("gh_repos_by_code_raw")
+    "rest_engine$search_for_code",
+    test_mocker$use("gh_search_repos_for_code")[["items"]]
+  )
+  mockery::stub(
+    github_testhost_priv$get_repos_with_code_from_host,
+    "private$parse_search_response",
+    test_mocker$use("gh_repos_raw_output")
   )
   repos_with_code_from_host_raw <- github_testhost_priv$get_repos_with_code_from_host(
     code = "shiny",
@@ -513,26 +405,6 @@ test_that("get_repos_with_code() works", {
   )
 })
 
-test_that("get_repos_with_code() works", {
-  mockery::stub(
-    github_testhost_priv$get_repos_with_code,
-    "private$get_repos_with_code_from_orgs",
-    test_mocker$use("repos_with_code_from_orgs_min")
-  )
-  github_repos_with_code_min <- github_testhost_priv$get_repos_with_code(
-    code = "test-code",
-    output = "table_min",
-    verbose = FALSE,
-    progress = FALSE
-  )
-  expect_repos_table(
-    github_repos_with_code_min,
-    repo_cols = repo_min_colnames
-  )
-  test_mocker$cache(github_repos_with_code_min)
-})
-
-
 test_that("get_repos_with_code() scans whole host", {
   github_testhost_priv <- create_github_testhost(
     mode = "private"
@@ -566,9 +438,10 @@ test_that("GitHub prepares repos table from repositories response", {
 test_that("get_repos_from_org works", {
   mockery::stub(
     github_testhost_priv$get_repos_from_orgs,
-    "graphql_engine$prepare_repos_table",
-    test_mocker$use("gh_repos_table")
+    "graphql_engine$get_repos_from_org",
+    test_mocker$use("gh_repos_from_org")
   )
+  github_testhost_priv$orgs <- gh_org
   gh_repos_from_orgs <- github_testhost_priv$get_repos_from_orgs(
     verbose = FALSE,
     progress = FALSE
@@ -634,7 +507,7 @@ test_that("`get_all_repos()` is set to scan whole git host", {
   )
   mockery::stub(
     github_testhost_all_priv$get_all_repos,
-    "graphql_engine$get_orgs",
+    "private$get_orgs_from_host",
     "test_org"
   )
   mockery::stub(
@@ -647,8 +520,8 @@ test_that("`get_all_repos()` is set to scan whole git host", {
     "private$get_repos_from_repos",
     test_mocker$use("gh_repos_individual")
   )
-  expect_snapshot(
-    gh_repos <- github_testhost_all_priv$get_all_repos(
+  expect_repos_table(
+    github_testhost_all_priv$get_all_repos(
       verbose  = TRUE,
       progress = FALSE
     )
@@ -673,7 +546,6 @@ test_that("add_platform adds data on Git platform to repos table", {
   test_mocker$cache(gh_repos_table_with_platform)
 })
 
-
 test_that("get_contributors_from_repo", {
   mockery::stub(
     test_rest_github_priv$get_contributors_from_repo,
@@ -719,8 +591,8 @@ test_that("`get_repos_contributors()` works on GitHost level", {
   expect_snapshot(
     gh_repos_with_contributors <- github_testhost_priv$get_repos_contributors(
       repos_table = test_mocker$use("gh_repos_table_with_platform"),
-      verbose     = TRUE,
-      progress    = FALSE
+      verbose = TRUE,
+      progress = FALSE
     )
   )
   expect_repos_table(
@@ -738,7 +610,7 @@ test_that("`get_repos()` works as expected", {
   mockery::stub(
     github_testhost$get_repos,
     "private$get_all_repos",
-    test_mocker$use("gh_repos_table")
+    test_mocker$use("gh_repos_table_with_platform")
   )
   gh_repos_table <- github_testhost$get_repos(
     add_contributors = FALSE,
@@ -755,7 +627,7 @@ test_that("`get_repos()` works as expected", {
   mockery::stub(
     github_testhost$get_repos,
     "private$get_all_repos",
-    test_mocker$use("gh_repos_table")
+    test_mocker$use("gh_repos_table_with_platform")
   )
   mockery::stub(
     github_testhost$get_repos,
@@ -772,34 +644,3 @@ test_that("`get_repos()` works as expected", {
   )
   test_mocker$cache(gh_repos_table_full)
 })
-
-test_that("`get_repos()` pulls table in minimalist version", {
-  mockery::stub(
-    github_testhost$get_repos,
-    "private$get_repos_with_code",
-    test_mocker$use("github_repos_with_code_min")
-  )
-  gh_repos_table_min <- github_testhost$get_repos(
-    add_contributors = FALSE,
-    with_code = "test_code",
-    output = "table_min",
-    verbose = FALSE
-  )
-  expect_repos_table(
-    gh_repos_table_min,
-    repo_cols = repo_min_colnames,
-    with_cols = c("api_url", "platform")
-  )
-  gh_repos_table_min <- github_testhost$get_repos(
-    add_contributors = FALSE,
-    with_file = "test_file",
-    output = "table_min",
-    verbose = FALSE
-  )
-  expect_repos_table(
-    gh_repos_table_min,
-    repo_cols = repo_min_colnames,
-    with_cols = c("api_url", "platform")
-  )
-  test_mocker$cache(gh_repos_table_min)
-})
