@@ -7,6 +7,14 @@ test_that("repos queries are built properly", {
   test_mocker$cache(gl_repos_by_org_query)
 })
 
+test_that("repos queries are built properly", {
+  gl_repos_query <-
+    test_gqlquery_gl$repos("")
+  expect_snapshot(
+    gl_repos_query
+  )
+})
+
 test_that("`get_repos_page()` pulls repos page from GitLab group", {
   mockery::stub(
     test_graphql_gitlab_priv$get_repos_page,
@@ -121,12 +129,12 @@ test_that("`get_repos_from_org()` does not fail when GraphQL response is not com
 
 test_that("`search_for_code()` works", {
   mockery::stub(
-    test_rest_gitlab_priv$search_for_code,
+    test_rest_gitlab$search_for_code,
     "self$response",
-    list()
+    list() # output not mocked as falls into infinite loop
   )
   expect_snapshot(
-    gl_search_repos_by_code <- test_rest_gitlab_priv$search_for_code(
+    gl_search_repos_by_code <- test_rest_gitlab$search_for_code(
       code = "test",
       filename = "TESTFILE",
       verbose = TRUE,
@@ -137,12 +145,12 @@ test_that("`search_for_code()` works", {
 
 test_that("`search_repos_for_code()` works", {
   mockery::stub(
-    test_rest_gitlab_priv$search_repos_for_code,
+    test_rest_gitlab$search_repos_for_code,
     "self$response",
     list()
   )
   expect_snapshot(
-    gl_search_repos_by_code <- test_rest_gitlab_priv$search_repos_for_code(
+    gl_search_repos_by_code <- test_rest_gitlab$search_repos_for_code(
       code = "test",
       repos = "TestRepo",
       filename = "TESTFILE",
@@ -152,21 +160,8 @@ test_that("`search_repos_for_code()` works", {
   )
 })
 
-test_that("`map_search_into_repos()` works", {
-  gl_search_response <- test_fixtures$gitlab_search_response
-  test_mocker$cache(gl_search_response)
-  gl_search_repos_by_code <- test_rest_gitlab_priv$map_search_into_repos(
-    gl_search_response,
-    progress = FALSE
-  )
-  expect_gl_repos_rest_response(
-    gl_search_repos_by_code
-  )
-  test_mocker$cache(gl_search_repos_by_code)
-})
-
 test_that("`get_repos_languages()` works", {
-  repos_list <- test_mocker$use("gl_search_repos_by_code")
+  repos_list <- test_mocker$use("gl_repos_from_org")
   repos_list[[1]]$id <- "45300912"
   mockery::stub(
     test_rest_gitlab_priv$get_repos_languages,
@@ -182,56 +177,6 @@ test_that("`get_repos_languages()` works", {
   test_mocker$cache(gl_repos_list_with_languages)
 })
 
-test_that("`get_repos_by_code()` works", {
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$search_for_code",
-    test_fixtures$gitlab_search_response
-  )
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$map_search_into_repos",
-    test_mocker$use("gl_search_repos_by_code")
-  )
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$get_repos_languages",
-    test_mocker$use("gl_repos_list_with_languages")
-  )
-  gl_repos_by_code <- test_rest_gitlab$get_repos_by_code(
-    code = "test",
-    org = "test_org"
-  )
-  expect_gl_repos_rest_response(
-    gl_repos_by_code
-  )
-})
-
-test_that("`get_repos_by_code()` works", {
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$search_repos_for_code",
-    test_fixtures$gitlab_search_response
-  )
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$map_search_into_repos",
-    test_mocker$use("gl_search_repos_by_code")
-  )
-  mockery::stub(
-    test_rest_gitlab$get_repos_by_code,
-    "private$get_repos_languages",
-    test_mocker$use("gl_repos_list_with_languages")
-  )
-  gl_repos_by_code <- test_rest_gitlab$get_repos_by_code(
-    code = "test",
-    repos = c("TestRepo1", "TestRepo2")
-  )
-  expect_gl_repos_rest_response(
-    gl_repos_by_code
-  )
-})
-
 test_that("`prepare_repos_table()` prepares repos table", {
   gl_repos_table <- test_graphql_gitlab$prepare_repos_table(
     repos_list = test_mocker$use("gl_repos_from_org"),
@@ -246,9 +191,10 @@ test_that("`prepare_repos_table()` prepares repos table", {
 test_that("get_repos_from_org prints proper message", {
   mockery::stub(
     gitlab_testhost_priv$get_repos_from_orgs,
-    "graphql_engine$prepare_repos_table",
-    test_mocker$use("gl_repos_table")
+    "graphql_engine$get_repos_from_org",
+    test_mocker$use("gl_repos_from_org")
   )
+  gitlab_testhost_priv$orgs <- "test_group"
   expect_snapshot(
     gl_repos_from_orgs <- gitlab_testhost_priv$get_repos_from_orgs(
       verbose = TRUE,
@@ -261,6 +207,42 @@ test_that("get_repos_from_org prints proper message", {
   test_mocker$cache(gl_repos_from_orgs)
 })
 
+test_that("get_repos_ids", {
+  repos_ids <- gitlab_testhost_priv$get_repos_ids(
+    search_response = test_fixtures$gitlab_search_response
+  )
+  expect_type(
+    repos_ids,
+    "double"
+  )
+  expect_gt(
+    length(repos_ids), 0
+  )
+})
+
+test_that("parse_search_response works", {
+  mockery::stub(
+    gitlab_testhost_priv$parse_search_response,
+    "graphql_engine$get_repos_from_org",
+    test_mocker$use("gl_repos_from_org")
+  )
+  gl_repos_raw_output <- gitlab_testhost_priv$parse_search_response(
+    search_response = test_fixtures$gitlab_search_response,
+    output = "raw"
+  )
+  expect_type(
+    gl_repos_raw_output,
+    "list"
+  )
+  expect_true(
+    all(names(gl_repos_raw_output[[1]]$node) %in% c("repo_id", "repo_name", "repo_path",
+                                                    "repository", "stars", "forks", "created_at",
+                                                    "last_activity_at", "languages", "issues",
+                                                    "namespace", "repo_url"))
+  )
+  test_mocker$cache(gl_repos_raw_output)
+})
+
 test_that("GitHost adds `repo_api_url` column to GitLab repos table", {
   repos_table <- test_mocker$use("gl_repos_table")
   gl_repos_table_with_api_url <- gitlab_testhost_priv$add_repo_api_url(repos_table)
@@ -268,85 +250,16 @@ test_that("GitHost adds `repo_api_url` column to GitLab repos table", {
   test_mocker$cache(gl_repos_table_with_api_url)
 })
 
-test_that("`tailor_repos_response()` tailors precisely `repos_list`", {
-  gl_repos_by_code <- test_mocker$use("gl_search_repos_by_code")
-  gl_repos_by_code_tailored <-
-    test_rest_gitlab$tailor_repos_response(
-      repos_response = gl_repos_by_code,
-      output = "table_full"
-    )
-  gl_repos_by_code_tailored %>%
-    expect_type("list") %>%
-    expect_length(length(gl_repos_by_code))
 
-  expect_list_contains_only(
-    gl_repos_by_code_tailored[[1]],
-    c(
-      "repo_id", "repo_name", "created_at", "last_activity_at",
-      "forks", "stars", "languages", "issues_open",
-      "issues_closed", "organization"
-    )
-  )
-  expect_lt(
-    length(gl_repos_by_code_tailored[[1]]),
-    length(gl_repos_by_code[[1]])
-  )
-  test_mocker$cache(gl_repos_by_code_tailored)
-})
-
-test_that("`tailor_repos_response()` tailors precisely to minimal `repos_list`", {
-  gl_repos_by_code <- test_mocker$use("gl_search_repos_by_code")
-  gl_repos_by_code_tailored <-
-    test_rest_gitlab$tailor_repos_response(
-      repos_response = gl_repos_by_code,
-      output = "table_min"
-    )
-  gl_repos_by_code_tailored %>%
-    expect_type("list") %>%
-    expect_length(length(gl_repos_by_code))
-
-  expect_list_contains_only(
-    gl_repos_by_code_tailored[[1]],
-    c("repo_id", "repo_name", "created_at", "default_branch", "organization")
-  )
-  expect_lt(
-    length(gl_repos_by_code_tailored[[1]]),
-    length(gl_repos_by_code[[1]])
-  )
-})
-
-test_that("REST client prepares table from GitLab repositories response", {
-  gl_repos_by_code_table <- test_rest_gitlab$prepare_repos_table(
-    repos_list = test_mocker$use("gl_repos_by_code_tailored"),
-    verbose = FALSE
+test_that("add_platform adds data on Git platform to repos table", {
+  gl_repos_table_with_platform <- gitlab_testhost_priv$add_platform(
+    repos_table = test_mocker$use("gl_repos_table_with_api_url")
   )
   expect_repos_table(
-    gl_repos_by_code_table
+    gl_repos_table_with_platform,
+    with_cols = c("api_url", "platform")
   )
-  gl_repos_by_code_table <- gitlab_testhost_priv$add_repo_api_url(gl_repos_by_code_table)
-  test_mocker$cache(gl_repos_by_code_table)
-})
-
-test_that("`get_repos_issues()` adds issues to repos table", {
-  mockery::stub(
-    test_rest_gitlab$get_repos_issues,
-    "self$response",
-    test_fixtures$gitlab_issues_response
-  )
-  gl_repos_by_code_table <- test_mocker$use("gl_repos_by_code_table")
-  gl_repos_by_code_table <- test_rest_gitlab$get_repos_issues(
-    gl_repos_by_code_table,
-    progress = FALSE
-  )
-  expect_gt(
-    length(gl_repos_by_code_table$issues_open),
-    0
-  )
-  expect_gt(
-    length(gl_repos_by_code_table$issues_closed),
-    0
-  )
-  test_mocker$cache(gl_repos_by_code_table)
+  test_mocker$cache(gl_repos_table_with_platform)
 })
 
 test_that("`get_repos_contributors()` adds contributors to repos table", {
@@ -355,17 +268,17 @@ test_that("`get_repos_contributors()` adds contributors to repos table", {
     "private$get_contributors_from_repo",
     "Maciej Banas"
   )
-  gl_repos_table_with_contributors <- test_rest_gitlab$get_repos_contributors(
-    test_mocker$use("gl_repos_table_with_api_url"),
+  gl_repos_table_full <- test_rest_gitlab$get_repos_contributors(
+    test_mocker$use("gl_repos_table_with_platform"),
     progress = FALSE
   )
   expect_repos_table(
-    gl_repos_table_with_contributors,
-    with_cols = c("api_url", "contributors")
+    gl_repos_table_full,
+    with_cols = c("api_url", "platform", "contributors")
   )
   expect_gt(
-    length(gl_repos_table_with_contributors$contributors),
+    length(gl_repos_table_full$contributors),
     0
   )
-  test_mocker$cache(gl_repos_table_with_contributors)
+  test_mocker$cache(gl_repos_table_full)
 })
