@@ -11,8 +11,9 @@ test_that("get_storage works", {
     "tbl"
   )
   expect_true(
-    all(names(gitstats_storage) %in% c("repositories", "commits", "users",
-                                       "files", "files_structure",
+    all(names(gitstats_storage) %in% c("organizations", "repositories",
+                                       "commits", "issues",
+                                       "users", "files", "files_structure",
                                        "release_logs", "R_package_usage"))
   )
 })
